
/*******************************************************************************
* Copyright (c) 2017 Olivier Langella <olivier.langella@u-psud.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <olivier.langella@u-psud.fr> - initial API and implementation
******************************************************************************/

#ifndef PEPTIDEMATCH_H
#define PEPTIDEMATCH_H
#include <pappsomspp/msrun/msrunid.h>
#include <pappsomspp/types.h>
#include <pappsomspp/peptide/peptide.h>
#include "identification_sources/identificationdatasource.h"

class PeptideMatch
{
public :
    PeptideMatch(pappso::MsRunIdSp msrunid_sp, unsigned int scan);

    void setRetentionTime(pappso::pappso_double rt);
    void setEvalue(pappso::pappso_double evalue);
    void setExperimentalMass(pappso::pappso_double exp_mass);
    void setStart(unsigned int start);
    void setCharge(unsigned int charge);
    void setPeptideSp (pappso::PeptideSp peptide);
    void setIdentificationDataSource(IdentificationDataSource* identification_source);
    void setChecked(bool arg1);


private :
    pappso::MsRunIdSp _msrunid_sp;
    unsigned int _scan;
    pappso::PeptideSp _peptide_sp;
    pappso::pappso_double _rt;
    pappso::pappso_double _evalue;
    pappso::pappso_double _exp_mass;
    unsigned int _start;
    unsigned int _charge;
    IdentificationDataSource* _p_identification_source = nullptr;
    
    /** @brief manually checked by user (true by default)
     */
    bool _checked = true;
    
    /** @brief automatic filter result (false by default)
     */
    bool _proxy_valid = false;
};

#endif // PEPTIDEMATCH_H
