
/*******************************************************************************
* Copyright (c) 2015 Olivier Langella <Olivier.Langella@moulon.inra.fr>.
*
* This file is part of XTPcpp.
*
*     XTPcpp is free software: you can redistribute it and/or modify
*     it under the terms of the GNU General Public License as published by
*     the Free Software Foundation, either version 3 of the License, or
*     (at your option) any later version.
*
*     XTPcpp is distributed in the hope that it will be useful,
*     but WITHOUT ANY WARRANTY; without even the implied warranty of
*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*     GNU General Public License for more details.
*
*     You should have received a copy of the GNU General Public License
*     along with XTPcpp.  If not, see <http://www.gnu.org/licenses/>.
*
* Contributors:
*     Olivier Langella <Olivier.Langella@moulon.inra.fr> - initial API and implementation
******************************************************************************/

#include "proteintablemodel.h"

#include <QDebug>


ProteinTableProxyModel::ProteinTableProxyModel(QObject *parent,ProteinTableModel* protein_table_model_p): QSortFilterProxyModel(parent),
    m_minGravity(0.0), m_minDensity(0.0)
{
    _protein_table_model_p = protein_table_model_p;
}

bool ProteinTableProxyModel::filterAcceptsRow(int source_row,
        const QModelIndex &source_parent) const {
    //return _protein_table_model_p->acceptRow(source_row);
	  return true;
}

bool ProteinTableProxyModel::lessThan(const QModelIndex & left, const QModelIndex & right) const {
    QVariant leftData = sourceModel()->data(left);
    QVariant rightData = sourceModel()->data(right);
    if (leftData.type() == QVariant::UInt) {
        return leftData.toUInt() < rightData.toUInt();
    }
    if (leftData.type() == QVariant::Int) {
        return leftData.toInt() < rightData.toInt();
    }
    return leftData.toString() < rightData.toString();
    //if (leftData.type() == QVariant::DateTime) {
    //   return leftData.toDateTime() < rightData.toDateTime();
    //} else {
    // static QRegExp emailPattern("[\\w\\.]*@[\\w\\.]*)");
    /*
            QString leftString = leftData.toString();
            if(left.column() == 1 && emailPattern.indexIn(leftString) != -1)
                leftString = emailPattern.cap(1);

            QString rightString = rightData.toString();
            if(right.column() == 1 && emailPattern.indexIn(rightString) != -1)
                rightString = emailPattern.cap(1);

            return QString::localeAwareCompare(leftString, rightString) < 0;
            */
    // }
}

QVariant ProteinTableProxyModel::headerData(int section, Qt::Orientation orientation,
        int role) const {
    return sourceModel()->headerData(section, orientation,
                                     role);
}

ProteinTableModel::ProteinTableModel(QObject *parent)
    :QAbstractTableModel(parent)
{

    //ui->tableView->show();
    // QModelIndex topLeft = createIndex(0,0);
    //emit a signal to make the view reread identified data
    //emit dataChanged(topLeft, topLeft);
}


void ProteinTableModel::setIdentificationGroup(IdentificationGroup * p_identification_group) {
    qDebug() << "ProteinTableModel::setIdentificationGroup begin " << p_identification_group->getProteinMatchList().size();
    _p_identification_group = p_identification_group;

    QModelIndex topLeft = createIndex(0,0);
    QModelIndex bottomRight = createIndex(rowCount(),columnCount());
    emit dataChanged(topLeft, bottomRight);
    emit headerDataChanged(Qt::Horizontal, 0,3);
}

int ProteinTableModel::rowCount(const QModelIndex &parent ) const {
    if (_p_identification_group != nullptr) {
        qDebug() << "ProteinTableModel::rowCount(const QModelIndex &parent ) " << _p_identification_group->getProteinMatchList().size();
        return _p_identification_group->getProteinMatchList().size();
    }
    return 0;
}
int ProteinTableModel::columnCount(const QModelIndex &parent ) const {
    return 3;
}
QVariant ProteinTableModel::headerData(int section, Qt::Orientation orientation, int role) const
{
    if (role == Qt::DisplayRole)
    {
        if (orientation == Qt::Horizontal) {
            switch (section)
            {
            case 0:
                return QString("group");
            case 1:
                return QString("subgroup");
            case 2:
                return QString("protein description");
            }
        }
    }
    return QVariant();
}
QVariant ProteinTableModel::data(const QModelIndex &index, int role ) const {
    // generate a log message when this method gets called
    int row = index.row();
    int col = index.column();
    qDebug() << QString("row %1, col%2, role %3")
             .arg(row).arg(col).arg(role);

    switch(role) {
    case Qt::CheckStateRole:

        if (col == 0) //add a checkbox to cell(1,0)
        {
            if ( _p_identification_group->getProteinMatchList().at(row)->isChecked()) {
                return Qt::Checked;
            }
            else {
                return Qt::Unchecked;
            }
        }
        break;
    case Qt::DisplayRole:
        if (col == 0) {
            if (_p_identification_group != nullptr) {

                return QVariant ((quint16) _p_identification_group->getProteinMatchList().at(row)->getPeptideMatchList().size());
            }
        }
        if (col == 1) {
            if (_p_identification_group != nullptr) {
                return _p_identification_group->getProteinMatchList().at(row)->getProteinSp().get()->getAccession();
            }
        }
        if (col == 2) {
            if (_p_identification_group != nullptr) {
                return _p_identification_group->getProteinMatchList().at(row)->getProteinSp().get()->getDescription();
            }
        }
        return QString("Row%1, Column%2")
               .arg(index.row() + 1)
               .arg(index.column() +1);
    }
    return QVariant();
}


bool ProteinTableModel::acceptRow(int source_row) {
    if (_p_identification_group->isValid(_p_identification_group->getProteinMatchList().at(source_row))) {
        return true;
    }
    return false;
}
